.. _about:

About POPPY
===================

Acknowledging or citing POPPY
--------------------------------

If you use this package for work or research presented in a publication
(whether directly, or as a dependency to another package), we would be grateful
if you could include the following acknowledgment:

  This research made use of POPPY, an open-source optical propagation Python
  package originally developed for the James Webb Space Telescope project
  (`Perrin, 2012 <http://adsabs.harvard.edu/abs/2012SPIE.8442E..3DP>`_).

You may also cite the `software code record at the Astrophysics Source Code Library <http://ascl.net/1602.018>`_.

.. _about_team:

The Team
-----------------

POPPY is developed primarily by a team of astronomers at the `Space Telescope
Science Insitute <http://www.stsci.edu/>`_, but is open to contributions from
scientists and software developers around the world. Development takes place
on Github at http://github.com/mperrin/poppy . See that page for the most up-to-date
list of contributors. 

Direct contributors to POPPY code
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

 * Marshall Perrin (@mperrin)
 * Joseph Long (@josephoenix)
 * Ewan Douglas (@douglase)
 * Neil Zimmerman (@neilzim)
 * Anand Sivaramakrishnan (@anand0xff)
 * Maciek Grochowicz (@maciekgroch)
 * Ted Corcovilos (@corcoted)
 * Kyle Douglass (@kmdouglas)
 * Christine Slocum (@cslocum)
 * Matt Mechtley (@mmechtley)

Indirect Contributors (algorithms, advice, ideas, inspirations)
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 * Erin Elliot
 * Remi Soummer
 * Laurent Pueyo
 * Charles Lajoie
 * Mark Sienkiewicz
 * Perry Greenfield

Contributors via Astropy Affiliated Package Template
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 * Mike Droetboom
 * Erik Bray
 * Erik Tollerud
 * Tom Robitaille
 * Matt Craig
 * Larry Bradley
 * Kyle Barbary
 * Christoph Deil
 * Adam Ginsburg
 * Wolfgang Kerzendorf
 * Hans Moritz Gunther
 * Benjamin Weaver
 * Brigitta Sipocz


This work was supported in part by the JWST mission, a joint effort of NASA,
ESA, and CSA, and by the WFIRST Phase-A mission development project. STScI
is operated on behalf of NASA by the Association of Universities for Research
in Astronomy.



License
-----------------

Copyright (C) 2010-2017 Association of Universities for Research in Astronomy (AURA)

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

    1. Redistributions of source code must retain the above copyright
       notice, this list of conditions and the following disclaimer.

    2. Redistributions in binary form must reproduce the above
       copyright notice, this list of conditions and the following
       disclaimer in the documentation and/or other materials provided
       with the distribution.

    3. The name of AURA and its representatives may not be used to
       endorse or promote products derived from this software without
       specific prior written permission.

THIS SOFTWARE IS PROVIDED BY AURA "AS IS" AND ANY EXPRESS OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL AURA BE LIABLE FOR ANY DIRECT, INDIRECT,
INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
DAMAGE.
